*** Replication file for Where and How is Money Spent on International Migration by World Bank Operational Projects?
*** David McKenzie, Charlotte Müller, and Pablo Acosta
version 18

sysdir set PLUS "SET/ADO/PATH/HERE"


*** Set directories
global maindir "SET/GLOBAL/PATH/HERE"

global figures "$maindir/figures"
global tables "$maindir/tables"
global data "$maindir/Data"

*** Install packages
* ssc install wbopendata
ssc install spmap, replace

** install other packages
ssc install geo2xy, replace     
ssc install palettes, replace        
ssc install colrspace, replace
ssc install schemepack, replace



************************************************************************
**** Map Data                                                        ***
************************************************************************
** Download official World Bank map files from Development Data Hub
* https://datacatalog.worldbank.org/int/search/dataset/0038272?_gl=1*ss29js*_gcl_au*MjIwODAyNTA1LjE3MjU2MjY2ODM.
* Convert into Stata files
cd "$maindir/Data/Mapboundaries"
spshape2dta WB_countries_Admin0_10m, replace saving(world)
* this creates world_shp.dta and world.dta

use "$maindir/Data/Mapboundaries/world.dta", clear
drop if TYPE=="Dependency"|TYPE=="Lease"
* drop dutch islands
drop if WB_A3=="BES"
distinct WB_A3
save "$maindir/Data/Mapboundaries/worldwb.dta", replace

use "$maindir/Data/Mapboundaries/world_shp.dta", clear
sort _ID
merge m:1 _ID using "$maindir/Data/Mapboundaries/worldwb.dta"
tab _merge 
drop if _merge==1
drop _merge 
sort _ID
save "$maindir/Data/Mapboundaries/world_shpwb.dta", replace

use "$maindir/Data/Mapboundaries/world-c.dta", clear
// Make sure the coordinates are inside the (-180,180) bounds   
*replace _X = 180 if _X > 180 & _X!=.
* Drop Antarctica
drop if _Y<-60
geo2xy _Y _X, proj(web_mercator) replace
save "$maindir/Data/Mapboundaries/world-cm.dta", replace

use "$maindir/Data/Mapboundaries/world-c.dta", clear
drop if _Y<-60
save "$maindir/Data/Mapboundaries/world-cc.dta", replace


*************************************************************************************
*** Construct Country-level variables from WDI to merge with migration data base   **
*************************************************************************************
use "$data/WDIextract.dta", clear

** destring 
for num 10/23: destring YR20X, force replace

** GDP per capita, migrant stock etc take from 2015 if not available
gen gdppc=YR2015 if SeriesCode=="NY.GDP.PCAP.KD"
label var gdppc "GDP per capita in constant US$"
gen migrantpc=YR2015 if SeriesCode=="SM.POP.TOTL.ZS"
label var migrantpc "Migrant stock per capita"
gen migrantstock=YR2015 if SeriesCode=="SM.POP.TOTL"
label var migrantstock "Total migrant stock"
gen population=YR2015 if SeriesCode=="SP.POP.TOTL"
label var population "Total population"
egen totalloans=rowmean(YR2010-YR2022) if SeriesCode=="DT.DOD.MWBG.CD"
label var totalloans "Average amount of IDA/IBRD loans 2010-22"
egen remittancesgdp=rowmean(YR2010-YR2022) if SeriesCode=="BX.TRF.PWKR.DT.GD.ZS"
label var remittancesgdp "Average remittances as percent of GDP"
egen refugeeshosted=rowmean(YR2010-YR2022) if SeriesCode=="SM.POP.REFG"
label var refugeeshosted "Total refugees hosted"
egen refugeessent=rowmean(YR2010-YR2022) if SeriesCode=="SM.POP.REFG.OR"
label var refugeessent "Refugees sent/originated total"

collapse (max) gdppc migrantpc migrantstock population totalloans remittancesgdp refugeeshosted refugeessent, by(CountryCode CountryName)
gen refugeespercap=refugeeshosted/population 
label var refugeespercap "Refugees hosted per capita"

sort CountryCode
drop if CountryCode==""
save "$data/WDIvars.dta", replace

*** Construct Migrant Stock Data from WDR bilateral stock 
use "$data/WBMM_1960_2020.dta", clear
* keep 2010
keep if year==2010
collapse (sum) mig, by(isoo CtryName_origin)
rename mig WDRmigrantstock
label var WDRmigrantstock "Migrant stock in 2010"
gen CountryCode=isoo
replace CountryCode="ROU" if CountryCode=="ROM"
replace CountryCode="TLS" if CountryCode=="TMP"
replace CountryCode="SRB" if CountryCode=="YUG"
replace CountryCode="COD" if CountryCode=="ZAR"
sort CountryCode 
save "$data/MigStock.dta", replace


**** Merge together with Migration projects database to form master data set *****
use "$data/WBMigrationProjects.dta", clear
* fix miscode in country
replace Country="ROU" if Country=="ROM"
gen CountryCode=Country
sort CountryCode 
merge CountryCode using "$data/WDIvars.dta"
tab _merge
rename _merge merge1
sort CountryCode 
merge CountryCode using "$data/IDAList.dta"
tab _merge
replace IDA=0 if _merge==1
drop _merge 
sort CountryCode
merge CountryCode using "$data/IBRDList.dta"
tab _merge
replace IBRD=0 if _merge==1
drop _merge

save "$data/MasterData.dta", replace

*** Merge in migrant stock data 
use "$data/MasterData.dta", clear
sort CountryCode 
merge CountryCode using  "$data/MigStock.dta"
tab _merge 
drop _merge
drop if CountryCode==""
sort CountryCode
save "$data/MasterData.dta", replace


**************************************************************************
***************** Analysis ***********************************************
***************************************************************************

use "$data/MasterData.dta", clear
* Set graph options
global graph_opts title(, justification(center) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid)  yscale(noline) xscale(noline) legend(region(lc(none) fc(none))) 

**********************************************
***How much lending for migration is there? **
**********************************************

***************************
**** Figure 1  ************
***************************
*** Number of Projects over time 

destring ApprovalFY, force replace

preserve 
gen project=1 if ProjectID~=""
collapse (sum) project, by(ApprovalFY)
list project ApprovalFY
twoway line project ApprovalFY if ApprovalFY>=2014 & ApprovalFY<=2023, xtitle("Approval Year") ytitle("Number of Projects")  ${graph_opts} title("Number of Lending Projects by Approval FY")
graph save "$figures/Fig1_projectsbyyear.gph", replace
graph export "$figures/Fig1_projectsbyyear.pdf", replace
graph export "$figures/Fig1_projectsbyyear.png", replace
restore

*** Amount of Financing
destring TotalFinancing WBFinancing MigAmount, force replace
sum TotalFinancing WBFinancing MigAmount if ApprovalFY>=2014 

preserve 
collapse (sum) TotalFinancing MigAmount, by(ApprovalFY)
list TotalFinancing MigAmount ApprovalFY if ApprovalFY~=.
label var TotalFinancing "Total Loan Amount"
label var MigAmount "Migration-Specific Components Amount"
twoway line TotalFinancing MigAmount ApprovalFY if ApprovalFY>=2014 &  ApprovalFY<=2023, xtitle("Approval Year") ytitle("Amount (US millions)")  ${graph_opts} title("Lending Volume by Approval FY") legend(rows(1) position(6) label(1 "Total Volume") label(2 "Migration-Specific Components"))
graph save "$figures/Fig1_volumebyyear.gph", replace
graph export "$figures/Fig1_volumebyyear.pdf", replace
graph export "$figures/Fig1_volumebyyear.png", replace
restore

graph combine "$figures/Fig1_projectsbyyear.gph" "$figures/Fig1_volumebyyear.gph", col(2) graphregion(color(white))
graph save "$figures/Figure1_howmuch.gph", replace
graph export "$figures/Figure1_howmuch.pdf", replace
graph export "$figures/Figure1_howmuch.png", replace


*** Total Amounts to report in the text
preserve
keep if ApprovalFY>=2014 
gen project=1 if ProjectID~=""
collapse (sum) project TotalFinancing MigAmount
list
restore

*** Biggest and Smallest operations by amount and by amount specific to migration
egen rank1=rank(TotalFinancing)
list ProjectID ProjectName TotalFinancing MigAmount if rank1<=3.5
list ProjectID ProjectName TotalFinancing MigAmount if rank1>=154 & rank1~=.
egen rank2=rank(MigAmount)
list ProjectID ProjectName TotalFinancing MigAmount if rank2>=100 & rank2~=.

************************************************************
***** Figure 2: Figures of types of loans used in projects *
************************************************************

gen project=1 if ProjectID~=""
destring Institution, force replace
label define institute 1 "IDA" 2 "IBRD" 3 "MIGA" 4 "IFC" 5 "IDA/IBRD Blend" 6 "Non WB"
label values Institution institute
graph bar (sum) project, over(Institution) title("Source of Funding") ytitle("Number of Projects")
graph save "$figures/FigHow1a.gph", replace

gen trustfunded=TrustFund~="" & TrustFund~="."
replace trustfunded=. if project==.|project==0
label define yesno 1 "Yes" 0 "No"
label values trustfunded yesno
graph bar (sum) project, over(trustfunded) title("Trust Funds Used?") ytitle("Number of Projects")
graph save "$figures/FigHow1b.gph", replace

gen financetype=FinancingInstrument
replace financetype=. if FinancingInstrument==1.3
label define loantypes 1 "IPF" 2 "DPF" 3 "PforR" 4 "TA" 5 "SIL" 6 "RAS" 7 "ERL"
label values financetype loantypes
graph bar (sum) project, over(financetype) title("Financing Instrument") ytitle("Number of Projects")
graph save "$figures/FigHow1c.gph", replace

destring GrantLoan, force replace
label define grantloan 1 "Loan only" 2 "Loan/Grant mix" 3 "Grant only"
label values GrantLoan grantloan
graph bar (sum) project, over(GrantLoan) title("Grant or Loan") ytitle("Number of Projects")
graph save "$figures/FigHow1d.gph", replace

graph combine "$figures/FigHow1a.gph" "$figures/FigHow1b.gph" "$figures/FigHow1c.gph" "$figures/FigHow1d.gph", col(2)
graph save "$figures/Figure2How.gph", replace
graph export "$figures/Figure2How.pdf", replace
graph export "$figures/Figure2How.png", replace


************************************************************************************
*** Where do these projects take place? ********************************************
************************************************************************************
**************************************
***** Figure 3: Region of Funding ****
**************************************
use "$data/MasterData.dta", clear

*** Number of projects by region
replace Region=1 if Region==7

label define regionnames 1 "SSA" 2 "EAP" 3 "ECA" 4 "LAC" 5 "MENA" 6 "SA" 7 "Other"
label values Region regionnames
gen project=1 if ProjectID~=""
graph bar (sum) project, over(Region) ytitle("Number of Projects") title("Number of Migration Lending Projects by Region 2014-24")
graph save "$figures/Figure3Where0.gph", replace
graph export "$figures/Figure3Where0.pdf", replace
graph export "$figures/Figure3Where0.png", replace			
		
******************************************
**** Figure 4: Map of Projects **********
*****************************************
		
tempfile tmp
*gen project=1 if ProjectID~=""
replace project=0 if project==.
collapse (sum) project, by(CountryCode CountryName)
drop if CountryName==""
drop if CountryCode==""
gen WB_A3=CountryCode
sort WB_A3 
replace WB_A3="ROM" if WB_A3=="ROU"
replace WB_A3="ZAR" if WB_A3=="COD"
replace WB_A3="TMP" if WB_A3=="TLS"
replace WB_A3="KSV" if WB_A3=="XKX"
replace WB_A3="AND" if WB_A3=="ADO"
merge WB_A3 using "$maindir/Data/Mapboundaries/worldwb.dta", sort
tab _merge 
keep if _merge==3
save `tmp', replace
sort _ID
*bin number of projects into groups
gen projectbin=0 if project==0
replace projectbin=1 if project==1
replace projectbin=2 if project>=2 & project<=5
replace projectbin=3 if project>=6 & project<=10
replace projectbin=4 if project>10 & project~=.
label define bins 0 "0" 1 "1" 2 "2-5" 3 "6-10" 4 "11+"
label values projectbin bins


spmap projectbin using "$maindir/Data/Mapboundaries/world_shpwb.dta", id(_ID)                                  ///
                 fcolor(Blues2) ocolor(black ..)  osize(vvthin)                                ///
				 clm(unique)   ///
                title("Number of World Bank Migration Lending Projects 2014-2024", size(*1.2))         ///
                legstyle(3) legend(ring(1) position(3) size(2)) legtitle("Number of Projects") 
graph save "$figures/Figure4Where.gph", replace
graph export "$figures/Figure4Where.pdf", replace
graph export "$figures/Figure4Where.png", replace			
			
********************************************************************************************
*** Figure 5: Scatterplots of number of projects against remittances per capita, refugees hosted per capita, and migrant stock per capita  *********************
use "$data/MasterData.dta", clear

gen project=1 if ProjectID~=""
replace project=0 if project==.
gen WDRmigrantstockpc=WDRmigrantstock/population

collapse (sum) nproject=project (max) gdppc migrantpc WDRmigrantstockpc WDRmigrantstock refugeespercap remittancesgdp IDA IBRD  population, by(CountryCode CountryName)
corr nproject gdppc migrantpc refugeespercap remittancesgdp WDRmigrantstockpc WDRmigrantstock if IDA==1|IBRD==1

sum refugeespercap if IDA==1|IBRD==1, de
gen highrefugeesproject=nproject if refugeespercap>r(p90) & refugeespercap~=.
twoway scatter nproject highrefugeesproject refugeespercap if (IDA==1|IBRD==1), legend(off) mlabel(CountryCode)
twoway scatter nproject highrefugeesproject refugeespercap if (IDA==1|IBRD==1), legend(off) mlabel(. CountryCode)

*** Figure 5A: Projects and Refugees Hosted per Capita
corr nproject refugeespercap if IDA==1|IBRD==1
cap drop project2
gen project2=nproject if CountryCode=="TUR"|CountryCode=="LBN"|CountryCode=="JOR"|CountryCode=="UGA"|CountryCode=="BGD"|CountryCode=="ETI"||CountryCode=="COL"|CountryCode=="CMR"|CountryCode=="DJI"
cap drop project3
gen project3=nproject if CountryCode=="PSE"|CountryCode=="NRU"
reg nproject refugeespercap if IDA==1|IBRD==1
predict fittedline, xb
twoway (scatter nproject project2 project3 refugeespercap if (IDA==1|IBRD==1), legend(off) mlabel(. CountryName CountryName) mcolor(eltblue eltblue eltblue) mlabposition(0 3 1)   ///
mlabcolor(black black black) mlabsize(small vsmall vsmall) xtitle("Refugees hosted per capita") ytitle("Number of Projects") ///
title("Number of Projects vs Refugees Hosted per Capita")) (line fittedline refugeespercap, lcolor(gs5))
graph save "$figures/Figure5ACorr1.gph", replace
graph export "$figures/Figure5ACorr1.pdf", replace
graph export "$figures/Figure5ACorr1.png", replace

*** Figure 5B: Projects and Remittances as Share of GDP
corr nproject remittancesgdp if IDA==1|IBRD==1
cap drop project3
gen project3=nproject if CountryCode=="MDA"|CountryCode=="WSM"|CountryCode=="NPL"|CountryCode=="TJK"|CountryCode=="LBN"|CountryCode=="TUR"|CountryCode=="COL"|CountryCode=="BGD"|CountryCode=="CMR"|CountryCode=="LBN"|CountryCode=="JOR"|CountryCode=="UGA"
gen project4=nproject if CountryCode=="TON"
gen project5=nproject if CountryCode=="KGZ"
reg nproject remittancesgdp if IDA==1|IBRD==1
predict remitfit, xb
twoway (scatter nproject project3 project4 project5 remittancesgdp if (IDA==1|IBRD==1), legend(off) mlabel(. CountryName CountryName CountryName) mcolor(eltblue eltblue eltblue eltblue) mlabposition(0 3 1 5)  ///
mlabcolor(black black black black) mlabsize(small vsmall vsmall vsmall) xtitle("Remittances to GDP (%)") ytitle("Number of Projects") ///
title("Number of Projects vs Remittance Share of GDP")) (line remitfit remittancesgdp, lcolor(gs5))
graph save "$figures/Figure5BCorr2.gph", replace
graph export "$figures/Figure5BCorr2.pdf", replace
graph export "$figures/Figure5BCorr2.png", replace

*** Figure 5C: Projects and Total Emigrants
corr nproject WDRmigrantstock if IDA==1|IBRD==1
gen migstockmills=WDRmigrantstock/1000000
label var migstockmills "Emigrant stock in millions"
list CountryCode 
cap drop project2 project3
gen project2=nproject if CountryCode=="BGD"|CountryCode=="CHN"|CountryCode=="IND"|CountryCode=="MEX"|CountryCode=="PAK"| ///
CountryCode=="RUS"|CountryCode=="UKR"|CountryCode=="COL"|CountryCode=="TUR"
gen project3=nproject if CountryCode=="PHL"|CountryCode=="AFG"

reg nproject migstockmills  if IDA==1|IBRD==1
predict migfit, xb
twoway (scatter nproject project2 project3 migstockmills if (IDA==1|IBRD==1), legend(off) mlabel(. CountryName CountryName) ///
 mcolor(eltblue eltblue eltblue) mlabposition(0 3 1) ///
mlabcolor(black black black) mlabsize(small vsmall vsmall) xtitle("Emigrant Stock (millions)") ytitle("Number of Projects") ///
title("Number of Projects vs EmigrantStock")) (line migfit migstockmills, lcolor(gs5))
graph save "$figures/Figure5CCorr3.gph", replace
graph export "$figures/Figure5CCorr3.pdf", replace
graph export "$figures/Figure5CCorr3.png", replace


*******************************************************
*** Table 1: Probit and Regression Estimates **********
*******************************************************
gen anyproject=cond(nproject>0 & nproject~=., 1, 0) if nproject~=.
label var anyproject "At least one project"

gen loggdppc=log(gdppc)
gen logWDRmigrantstock=log(WDRmigrantstock)
gen logpop=log(population)

**** Check ststo when online
eststo clear
probit anyproject loggdppc  IDA refugeespercap logWDRmigrantstock remittancesgdp logpop if (IDA==1|IBRD==1), r
estadd margins, dydx(*) post
sum anyproject if e(sample)
estadd local mean=round(r(mean), 0.01)
estadd local samplesize=r(N)
eststo Table1_1

reg nproject loggdppc  IDA refugeespercap logWDRmigrantstock remittancesgdp logpop if (IDA==1|IBRD==1), r
sum nproject if e(sample)
estadd local mean=round(r(mean), 0.01)
estadd local samplesize=r(N)
eststo Table1_2

#delimit ;
esttab Table1_* using "$tables/Table1.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se  star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(mean samplesize , fmt(%9.0f %9.2f) labels("Outcome Mean" "Sample Size" )) 
	title("Correlates of Migration Projects") addnotes("""") ;
#delimit cr


* interpret magnitudes
sum refugeespercap if (IDA==1|IBRD==1), de
list CountryCode CountryName refugeespercap if refugeespercap>=0.01 & refugeespercap~=. & (IDA==1|IBRD==1)

*******************************************************
**** Figure 6: What is the money being used for?    ***
*******************************************************
use "$data/MasterData.dta", clear

destring GP, gen(GPnew) force
gen project=1 if ProjectID~=""

replace GPnew=2 if GPnew==19
replace GPnew=6 if GPnew==22
replace GPnew=10 if GPnew==23
replace GPnew=13 if GPnew==21
replace GPnew=12 if GPnew==24
replace GPnew=1 if GPnew==25
replace GPnew=10 if GPnew==26
replace GPnew=6 if GPnew==27
replace GPnew=5 if GPnew==16
replace GPnew=9 if GP=="6, 9"


label define GPnames 1 "Agriculture" 2 "Digital" 3 "Education" 4 "Energy" 5 "Environment" 6 "Finance & Competitiveness" 7 "Governance" ///
8 "Health" 9 "Macro and Trade" 10 "Social Protection" 11 "Social Sustainability" 12 "Transport" 13 "Urban" 14 "Water" ///
15 "Fragile & Conflict" 17 "Gender" 18 "Poverty"  20 "Infrastructure"   
label values GPnew GPnames

graph hbar (sum) project, over(GPnew, sort(1) descending) title("Projects by World Bank Global Practice") ytitle("Number of Projects") 
graph save "$figures/Figure6What1a.gph", replace
graph export "$figures/Figure6What1a.pdf", replace
graph export "$figures/Figure6What1a.png", replace


**********************************************************
*** Figure 7: Type of migrants targeted  *****************
**********************************************************
preserve
cap drop noTarget
gen noTarget=1 if Refugees==0 & Workimmigrants==0 & Potentialemigrants==0 & Workersabroad==0 & Returnmigrants==0
replace noTarget=0 if noTarget==. & project~=.
collapse (mean) Refugees Workimmigrants Potentialemigrants Workersabroad Returnmigrants noTarget if project~=.
label var Refugees "Refugees"
label var Workimmigrants "Immigrants"
label var Potentialemigrants "Potential Emigrants"
label var Workersabroad "Migrants Abroad"
label var Returnmigrants "Return Migrants"
label var noTarget "none"
graph bar Refugees Workimmigrants Potentialemigrants Workersabroad Returnmigrants noTarget, title("Type of Migrants Targeted")  ///
ytitle("Proportion of Projects") showyvars legend(off)

gr_edit varaxis.style.editstyle majorstyle(use_labels(yes)) editcopy
gr_edit varaxis.style.editstyle majorstyle(alternate(no)) editcopy
gr_edit varaxis.style.editstyle majorstyle(use_labels(yes)) editcopy
gr_edit varaxis.style.editstyle majorstyle(alternate(no)) editcopy
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 1 10.9375 `"Refugees"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 2 26.5625 `"Workimmigrants"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 2 26.5625 `"Workimmigrants"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 3 42.1875 `"Emigrants"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 3 42.1875 `"Emigrants"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 4 57.8125 `"Workers Abroad"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 4 57.8125 `"Workers Abroad"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 5 73.4375 `"Returnees"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 5 73.4375 `"Returnees"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 6 89.0625 `"No specific"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 2 26.5625 `"Work immigrants"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 2 26.5625 `"Work Immigrants"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 2 26.5625 `"Work Immigrants"', tickset(major)
gr_edit plotregion1.bars[3].style.editstyle shadestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[3].style.editstyle linestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[4].style.editstyle shadestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[4].style.editstyle linestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[5].style.editstyle shadestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[5].style.editstyle linestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[6].style.editstyle shadestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[6].style.editstyle linestyle(color(stc1)) editcopy
graph save "$figures/Figure7.gph", replace
graph export "$figures/Figure7.png", replace
graph export "$figures/Figure7.pdf", replace
restore

*** labor mobility and coping with refugeeshosted
tab LaborMobility
tab CopingwithRefugees

***************************************************************************************
****Figure 8: Activities for Migrants and Refugees Included as Project Components  ****
***************************************************************************************
*** What does Project Development Objective include 
preserve 
* correct based on further reading
replace Monitoringworkerwelfare=1 if ProjectID=="P174594"
replace Reducingbarriers=1 if ProjectID=="P161541"
replace Reducingbarriers=1 if ProjectID=="P175483"
collapse (sum) WorkerReadiness Reducingbarriers Improvingrecruitment Monitoringworkerwelfare Remittancecost Remittancesfinancialinclusion Skillsdevelopment FinancialLiteracy Humanitarianassistance Entrepreneurship Languagetraining Employment Basicservicesaccess Legalbarriers Socialcohesion if project~=.
label var WorkerReadiness "Worker Readiness for Migrating"
label var Reducingbarriers "Reducing Barriers to Migrating"
graph hbar WorkerReadiness Reducingbarriers Improvingrecruitment Monitoringworkerwelfare Remittancecost Remittancesfinancialinclusion Skillsdevelopment FinancialLiteracy Humanitarianassistance Entrepreneurship Languagetraining Employment Basicservicesaccess Legalbarriers Socialcohesion, showyvars legend(off)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 1 4.54545 `"Strengthening Social Cohesion in Host"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 1 4.54545 `"Strengthening Social Cohesion in Host"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 2 11.039 `"Reducing Legal Barriers to Integration"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 3 17.5325 `"Access to Basic Services in Host"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 4 24.026 `"Employment Services in Host"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 5 30.5195 `"Language Training Courses"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 6 37.013 `"Entrepreneurship Programs"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 7 43.5065 `"Humanitarian Assistance"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 8 50 `"Financial Literacy"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 9 56.4935 `"Skills Development"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 10 62.987 `"Remittances and Financial Inclusion"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 11 69.4805 `"Reducing Remittance Costs"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 12 75.974 `"Monitoring Worker Welfare Abroad"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 13 82.4675 `"Improving Migration Recruitment"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 14 88.961 `"Reducing Barriers to Emigrating"', tickset(major)
gr_edit varaxis.major.num_rule_ticks = 0
gr_edit varaxis.edit_tick 15 95.4545 `"Worker Readiness for Emigration"', tickset(major)
gr_edit varaxis.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.bars[14].style.editstyle shadestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[14].style.editstyle linestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[13].style.editstyle shadestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[13].style.editstyle linestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[12].style.editstyle shadestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[12].style.editstyle linestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[11].style.editstyle shadestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[11].style.editstyle linestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[10].style.editstyle shadestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[10].style.editstyle linestyle(color(stc1)) editcopy
gr_edit plotregion1.bars[9].style.editstyle shadestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[9].style.editstyle linestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[8].style.editstyle shadestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[8].style.editstyle linestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[7].style.editstyle shadestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[7].style.editstyle linestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[6].style.editstyle shadestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[6].style.editstyle linestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[5].style.editstyle shadestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[5].style.editstyle linestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[4].style.editstyle shadestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[4].style.editstyle linestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[3].style.editstyle shadestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[3].style.editstyle linestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[2].style.editstyle shadestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[2].style.editstyle linestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[1].style.editstyle shadestyle(color(stc2)) editcopy
gr_edit plotregion1.bars[1].style.editstyle linestyle(color(stc2)) editcopy
gr_edit scaleaxis.title.text = {}
gr_edit scaleaxis.title.text.Arrpush Number of Projects
gr_edit title.text = {}
gr_edit title.text.Arrpush Detailed Project Components
graph save "$figures/Figure8.gph", replace
graph export "$figures/Figure8.png", replace
graph export "$figures/Figure8.pdf", replace
restore



*** Look at Specific Projects that have Development Goal of Migration
replace Monitoringworkerwelfare=1 if ProjectID=="P174594"
replace Reducingbarriers=1 if ProjectID=="P161541" 
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if WorkerReadiness==1
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if Reducingbarriers==1
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if Improvingrecruitment==1
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if Monitoringworkerwelfare==1
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if Remittancecost==1
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if Remittancesfinancialinclusion==1
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if LaborMobility==1
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if BetterPrepared==1

list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if Potentialemigrants==1
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if Workersabroad==1
list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if Returnmigrants==1

list ProjectID ProjectName CountryName Institution Concessional TrustFund FinancingInstrument TotalFinancing WBFinancing MigAmount ApprovalFY if CountryRole=="1"